---
title: Quick Start
hide:
- navigation
---

# PyEIO: Python Easy Input-Output

<div align="center">
<a href="https://pypi.org/project/pyeio/" target="_blank">
<img src="https://img.shields.io/pypi/v/pyeio" height=20 style="position: relative;">
</a>
<a href="https://github.com/harttraveller/pyeio/blob/main/LICENSE" target="_blank">
<img src="https://img.shields.io/badge/license-MIT-blue" height=20 style="position: relative;">
</a>
</div>

`pyeio` is a Python library meant to simplify file IO processes. It standardizes the API for various file formats and types, and adds various ease-of-development features.

## Installation



## Usage

<!-- 
## Design

If you plan on using this library, you should familiarize yourself with it's architecture. It is explicitly built to be as standardized, interoperable, and internally symmetrical as possible.

Cover:

- Base format modules, available functions, file format ontology and how categories in ontology are 1:1 mapped with functions in format modules
- Meta format modules
- Various available tools

## Ontology

- binary data
    - text data
        - unstructured text
        - structured text
            - data
                - hierarchical
                - array like
            - code
    - custom format
    - mixed format
        - PDF has text, also images, flate compressed data, etc
    - archive format

 -->